@@ -8,7 +8,7 @@ use FCGI::Engine::ProcManager;
 
 use constant DEBUG => 0;
 
-our $VERSION   = '0.15';
+our $VERSION   = '0.16';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'MooseX::Getopt',
@@ -57,6 +57,13 @@ has 'manager' => (
     cmd_aliases => 'M',
 );
 
+has 'use_manager' => (
+    metaclass => 'Getopt',
+    is        => 'ro',
+    isa       => 'Bool',
+    default   => 0,
+);
+
 # options to specify in your script
 
 has 'pre_fork_init' => (
@@ -174,6 +181,14 @@ sub run {
         $proc_manager->manage;
     }
 
+    # We do not listen but we do want more than one processes being forked and
+    # want to take the benefit of running the process manager as well. This
+    # makes sense if the FastCGI script is started directly via Apache.
+    elsif ( $self->use_manager ) {
+        $proc_manager = $self->create_proc_manager( %addtional_options );
+        $proc_manager->manage;
+    }
+
     while ($request->Accept() >= 0) {
 
         $proc_manager && $proc_manager->pre_dispatch;
